@@ -252,6 +252,8 @@ def test_fixture(module_path: str, fixture_folder: str, date: str = None, start_
     try:
         Class = parse_class_from_python_source(module_path.open('r').read())
     except SyntaxError as e:
+        if not e.text:
+            e.text = ''
         raise SyntaxError(f'Could not parse python file.\n  File "{module_path.absolute()}", line {e.lineno}\n    {e.text.strip()}\nSyntaxError: {e.msg}')
 
     # 2. load JSON folder of fixture data
